@@ -2,7 +2,10 @@ from typing import Tuple, List
 
 import pandas as pd
 import numpy as np
+import matplotlib.pyplot as plt
+
 from tonic_reporting.util import make_data_transformer, filter_null_and_match_row_counts
+from tonic_reporting.styling import Colors, PlotsSizes, FontSizes
 from sklearn.neighbors import BallTree
 from sklearn.neighbors import NearestNeighbors
 
@@ -28,8 +31,19 @@ def compute_dcr(
     X_real = column_transformer.transform(real_data)
     X_synth = column_transformer.transform(synth_data)
     tree = BallTree(X_real, leaf_size=2)
-    syn_distances, syn_indices = tree.query(X_synth, k=1)
+    synth_distances, syn_indices = tree.query(X_synth, k=1)
     nbrs = NearestNeighbors(n_neighbors=2, algorithm="ball_tree").fit(X_real)
     real_distances, real_indices = nbrs.kneighbors(X_real)
 
-    return syn_distances[:, 0], real_distances[:, 1]
+    return synth_distances[:, 0], real_distances[:, 1]
+
+
+def plot_dcr(source_df, synth_df, numeric_cols, categorical_cols):
+    syn_dcr, real_dcr = compute_dcr(source_df, synth_df, numeric_cols, categorical_cols)
+
+    fig, ax = plt.subplots(1, 1, figsize=(PlotsSizes.DEFAULT_WIDTH, PlotsSizes.DEFAULT_HEIGHT))
+    ax.hist(real_dcr, bins=300, label="Real vs. real", color=Colors.REAL)
+    ax.hist(syn_dcr, bins=300, label="Synthetic vs. real", color=Colors.SYNTH)
+    ax.tick_params(axis="both", which="major", labelsize=FontSizes.DEFAULT)
+    ax.legend(fontsize=FontSizes.LARGE)
+    plt.show(block=False)
