@@ -5,8 +5,9 @@ class Colors:
 
 
 class PlotsSizes:
-    LARGE_FIGURE = (16, 10)
-    XTRA_LARGE_FIGURE = (20, 10)
+    DEFAULT_WIDTH = 6
+    DEFAULT_HEIGHT = 4
+    TWO_COLUMNS = (12, 4)
 
 
 class Labels:
@@ -17,3 +18,8 @@ class Labels:
 class FontSizes:
     DEFAULT = 14
     LARGE = 16
+
+
+def format_stats_data(df):
+    format_kwargs = {col: "{:.2%}" for col in df.columns if "p-value" in col}
+    return df.style.format(format_kwargs)
